import {
  Column,
  Entity,
  JoinColumn,
  ManyToOne,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { InstitucionInfraccion } from '../../institucion-infraccion/entity/institucion-infraccion.entity';
import { Prestamo } from '../../prestamo/entity/prestamo.entity';
import { Operador } from '../../operador/entity/operador.entity';

@Entity()
export class Multa {
  @PrimaryGeneratedColumn()
  id_multa: number;

  @Column({ type: Boolean, nullable: false, default: true })
  activo: boolean;

  @Column({ type: String, nullable: false, length: 250 })
  descripcion: string;

  @Column({ type: Date, nullable: false })
  fecha_fin: Date;

  @Column({ type: Date, nullable: false })
  fecha_inicio: Date;

  @Column({ type: Boolean, nullable: false, default: false })
  retraso: boolean;

  @Column({ type: Number, nullable: true })
  id_institucion_infraccion: number;

  @Column({ type: Number, nullable: true })
  id_operador: number;

  @Column({ type: Number, nullable: true })
  id_prestamo: number;

  @ManyToOne(
    () => InstitucionInfraccion,
    (institucionInfraccion) => institucionInfraccion.multas,
    { eager: true },
  )
  @JoinColumn({ name: 'id_institucion_infraccion' })
  institucionInfraccion: InstitucionInfraccion;

  @ManyToOne(() => Operador, (operador) => operador.multas, { eager: true })
  @JoinColumn({ name: 'id_operador' })
  operadorMulta: Operador;

  @ManyToOne(() => Prestamo, (prestamo) => prestamo.multa)
  @JoinColumn({ name: 'id_prestamo' })
  prestamo: Prestamo;
}
